@@ -5,7 +5,7 @@ Credits:
 This file was adopted from: https://github.com/pydata/xarray # noqa
 Source file: https://github.com/pydata/xarray/blob/1d7bcbdc75b6d556c04e2c7d7a042e4379e15303/xarray/backends/rasterio_.py # noqa
 """
-
+# pylint: disable=too-many-lines
 import contextlib
 import functools
 import importlib.metadata
@@ -14,9 +14,10 @@ import re
 import threading
 import warnings
 from collections import defaultdict
-from typing import Any, Dict, Hashable, Iterable, List, Optional, Tuple, Union
+from collections.abc import Hashable, Iterable
+from typing import Any, Optional, Union
 
-import numpy as np
+import numpy
 import rasterio
 from numpy.typing import NDArray
 from packaging import version
@@ -36,23 +37,54 @@ from xarray.core.variable import as_variable
 from rioxarray.exceptions import RioXarrayError
 from rioxarray.rioxarray import _generate_spatial_coords
 
+FILL_VALUE_NAMES = ("_FillValue", "missing_value", "fill_value", "nodata")
+UNWANTED_RIO_ATTRS = ("nodatavals", "is_tiled", "res")
 # TODO: should this be GDAL_LOCK instead?
 RASTERIO_LOCK = SerializableLock()
 NO_LOCK = contextlib.nullcontext()
 
 
+def _ensure_warped_vrt(riods, vrt_params):
+    """
+    Ensuire the dataset is represented as a warped vrt
+    """
+    if vrt_params is None:
+        return riods
+    if isinstance(riods, SingleBandDatasetReader):
+        riods._create_vrt(vrt_params)
+    else:
+        riods = WarpedVRT(riods, **vrt_params)
+    return riods
+
+
 class SingleBandDatasetReader:
     """
     Hack to have a DatasetReader behave like it only has one band
     """
 
-    def __init__(self, riods, bidx) -> None:
+    def __init__(self, riods, bidx, vrt_params=None) -> None:
         self._riods = riods
         self._bidx = bidx
+        self._vrt_params = vrt_params
+        self._create_vrt(vrt_params=vrt_params)
 
     def __getattr__(self, __name: str) -> Any:
         return getattr(self._riods, __name)
 
+    def _create_vrt(self, vrt_params):
+        if vrt_params is not None and not isinstance(self._riods, WarpedVRT):
+            self._riods = WarpedVRT(self._riods, **vrt_params)
+        self._vrt_params = vrt_params
+
+    @property
+    def name(self):
+        """
+        str: name of the dataset. Usually the path.
+        """
+        if isinstance(self._riods, rasterio.vrt.WarpedVRT):
+            return self._riods.src_dataset.name
+        return self._riods.name
+
     @property
     def count(self):
         """
@@ -139,11 +171,11 @@ def _get_unsigned_dtype(unsigned, dtype):
     """
     Based on: https://github.com/pydata/xarray/blob/abe1e613a96b000ae603c53d135828df532b952e/xarray/coding/variables.py#L306-L334
     """
-    dtype = np.dtype(dtype)
+    dtype = numpy.dtype(dtype)
     if unsigned is True and dtype.kind == "i":
-        return np.dtype(f"u{dtype.itemsize}")
+        return numpy.dtype(f"u{dtype.itemsize}")
     if unsigned is False and dtype.kind == "u":
-        return np.dtype(f"i{dtype.itemsize}")
+        return numpy.dtype(f"i{dtype.itemsize}")
     return None
 
 
@@ -274,9 +306,7 @@ class RasterioArrayWrapper(BackendArray):
         self.mask_and_scale = mask_and_scale
 
         # cannot save riods as an attribute: this would break pickleability
-        riods = manager.acquire()
-        if vrt_params is not None:
-            riods = WarpedVRT(riods, **vrt_params)
+        riods = _ensure_warped_vrt(manager.acquire(), vrt_params)
         self.vrt_params = vrt_params
         self._shape = (riods.count, riods.height, riods.width)
 
@@ -284,7 +314,7 @@ class RasterioArrayWrapper(BackendArray):
         self._unsigned_dtype = None
         self._fill_value = riods.nodata
         dtypes = riods.dtypes
-        if not np.all(np.asarray(dtypes) == dtypes[0]):
+        if not numpy.all(numpy.asarray(dtypes) == dtypes[0]):
             raise ValueError("All bands should have the same dtype")
 
         dtype = _rasterio_to_numpy_dtype(dtypes)
@@ -355,9 +385,9 @@ class RasterioArrayWrapper(BackendArray):
         # bands (axis=0) cannot be windowed but they can be listed
         if isinstance(band_key, slice):
             start, stop, step = band_key.indices(self.shape[0])
-            band_key = np.arange(start, stop, step)
+            band_key = numpy.arange(start, stop, step)
         # be sure we give out a list
-        band_key = (np.asarray(band_key) + 1).tolist()
+        band_key = (numpy.asarray(band_key) + 1).tolist()
         if isinstance(band_key, list):  # if band_key is not a scalar
             np_inds.append(slice(None))
 
@@ -376,13 +406,13 @@ class RasterioArrayWrapper(BackendArray):
                 start = ikey
                 stop = ikey + 1
             else:
-                start, stop = np.min(ikey), np.max(ikey) + 1
+                start, stop = numpy.min(ikey), numpy.max(ikey) + 1
                 np_inds.append(ikey - start)
             window.append((start, stop))
 
-        if isinstance(key[1], np.ndarray) and isinstance(key[2], np.ndarray):
+        if isinstance(key[1], numpy.ndarray) and isinstance(key[2], numpy.ndarray):
             # do outer-style indexing
-            np_inds[-2:] = np.ix_(*np_inds[-2:])
+            np_inds[-2:] = numpy.ix_(*np_inds[-2:])
 
         return band_key, tuple(window), tuple(squeeze_axis), tuple(np_inds)
 
@@ -391,17 +421,17 @@ class RasterioArrayWrapper(BackendArray):
         if not band_key or any(start == stop for (start, stop) in window):
             # no need to do IO
             shape = (len(band_key),) + tuple(stop - start for (start, stop) in window)
-            out = np.zeros(shape, dtype=self.dtype)
+            out = numpy.zeros(shape, dtype=self.dtype)
         else:
             with self.lock:
-                riods = self.manager.acquire(needs_lock=False)
-                if self.vrt_params is not None:
-                    riods = WarpedVRT(riods, **self.vrt_params)
+                riods = _ensure_warped_vrt(
+                    self.manager.acquire(needs_lock=False), self.vrt_params
+                )
                 out = riods.read(band_key, window=window, masked=self.masked)
                 if self._unsigned_dtype is not None:
                     out = out.astype(self._unsigned_dtype)
                 if self.masked:
-                    out = np.ma.filled(out.astype(self.dtype), self.fill_value)
+                    out = numpy.ma.filled(out.astype(self.dtype), self.fill_value)
                 if self.mask_and_scale:
                     if not isinstance(band_key, Iterable):
                         out = (
@@ -409,14 +439,14 @@ class RasterioArrayWrapper(BackendArray):
                             + riods.offsets[band_key - 1]
                         )
                     else:
-                        for iii, band_iii in enumerate(np.atleast_1d(band_key) - 1):
+                        for iii, band_iii in enumerate(numpy.atleast_1d(band_key) - 1):
                             out[iii] = (
                                 out[iii] * riods.scales[band_iii]
                                 + riods.offsets[band_iii]
                             )
 
         if squeeze_axis:
-            out = np.squeeze(out, axis=squeeze_axis)
+            out = numpy.squeeze(out, axis=squeeze_axis)
         return out[np_inds]
 
     def __getitem__(self, key):
@@ -445,7 +475,7 @@ def _parse_envi(meta):
     """
 
     def parsevec(value):
-        return np.fromstring(value.strip("{}"), dtype="float", sep=",")
+        return numpy.fromstring(value.strip("{}"), dtype="float", sep=",")
 
     def default(value):
         return value.strip("{}")
@@ -457,11 +487,11 @@ def _parse_envi(meta):
 
 def _rasterio_to_numpy_dtype(dtypes):
     """Numpy dtype from first entry of rasterio dataset.dtypes"""
-    # rasterio has some special dtype names (complex_int16 -> np.complex64)
+    # rasterio has some special dtype names (complex_int16 -> numpy.complex64)
     if dtypes[0] == "complex_int16":
-        dtype = np.dtype("complex64")
+        dtype = numpy.dtype("complex64")
     else:
-        dtype = np.dtype(dtypes[0])
+        dtype = numpy.dtype(dtypes[0])
 
     return dtype
 
@@ -480,12 +510,12 @@ def _to_numeric(value: Any) -> float:
     return value
 
 
-def _parse_tag(key: str, value: Any) -> Tuple[str, Any]:
+def _parse_tag(key: str, value: Any) -> tuple[str, Any]:
     # NC_GLOBAL is appended to tags with netcdf driver and is not really needed
     key = key.split("NC_GLOBAL#")[-1]
     if value.startswith("{") and value.endswith("}"):
         try:
-            new_val = np.fromstring(value.strip("{}"), dtype="float", sep=",")
+            new_val = numpy.fromstring(value.strip("{}"), dtype="float", sep=",")
             # pylint: disable=len-as-condition
             value = new_val if len(new_val) else _to_numeric(value)
         except ValueError:
@@ -495,7 +525,7 @@ def _parse_tag(key: str, value: Any) -> Tuple[str, Any]:
     return key, value
 
 
-def _parse_tags(tags: Dict) -> Dict:
+def _parse_tags(tags: dict) -> dict:
     parsed_tags = {}
     for key, value in tags.items():
         key, value = _parse_tag(key, value)
@@ -505,22 +535,22 @@ def _parse_tags(tags: Dict) -> Dict:
 
 NETCDF_DTYPE_MAP = {
     0: object,  # NC_NAT
-    1: np.byte,  # NC_BYTE
-    2: np.char,  # NC_CHAR
-    3: np.short,  # NC_SHORT
-    4: np.int_,  # NC_INT, NC_LONG
+    1: numpy.byte,  # NC_BYTE
+    2: numpy.char,  # NC_CHAR
+    3: numpy.short,  # NC_SHORT
+    4: numpy.int_,  # NC_INT, NC_LONG
     5: float,  # NC_FLOAT
-    6: np.double,  # NC_DOUBLE
-    7: np.ubyte,  # NC_UBYTE
-    8: np.ushort,  # NC_USHORT
-    9: np.uint,  # NC_UINT
-    10: np.int64,  # NC_INT64
-    11: np.uint64,  # NC_UINT64
+    6: numpy.double,  # NC_DOUBLE
+    7: numpy.ubyte,  # NC_UBYTE
+    8: numpy.ushort,  # NC_USHORT
+    9: numpy.uint,  # NC_UINT
+    10: numpy.int64,  # NC_INT64
+    11: numpy.uint64,  # NC_UINT64
     12: object,  # NC_STRING
 }
 
 
-def _load_netcdf_attrs(tags: Dict, data_array: DataArray) -> None:
+def _load_netcdf_attrs(tags: dict, data_array: DataArray) -> None:
     """
     Loads the netCDF attributes into the data array
 
@@ -541,7 +571,7 @@ def _parse_netcdf_attr_array(attr: Union[NDArray, str], dtype=None) -> NDArray:
     """
     Expected format: '{2,6}' or '[2. 6.]'
     """
-    value: Union[NDArray, str, List]
+    value: Union[NDArray, str, list]
     if isinstance(attr, str):
         if attr.startswith("{"):
             value = attr.strip("{}").split(",")
@@ -551,10 +581,10 @@ def _parse_netcdf_attr_array(attr: Union[NDArray, str], dtype=None) -> NDArray:
         value = [attr]
     else:
         value = attr
-    return np.array(value, dtype=dtype)
+    return numpy.array(value, dtype=dtype)
 
 
-def _load_netcdf_1d_coords(tags: Dict) -> Dict:
+def _load_netcdf_1d_coords(tags: dict) -> dict:
     """
     Dimension information:
         - NETCDF_DIM_EXTRA: '{time}' (comma separated list of dim names)
@@ -579,8 +609,8 @@ def _load_netcdf_1d_coords(tags: Dict) -> Dict:
 
 
 def build_subdataset_filter(
-    group_names: Optional[Union[str, List[str], Tuple[str, ...]]],
-    variable_names: Optional[Union[str, List[str], Tuple[str, ...]]],
+    group_names: Optional[Union[str, list[str], tuple[str, ...]]],
+    variable_names: Optional[Union[str, list[str], tuple[str, ...]]],
 ):
     """
     Example::
@@ -626,6 +656,10 @@ def _get_rasterio_attrs(riods: RasterioReader):
     # pylint: disable=too-many-branches
     # Add rasterio attributes
     attrs = _parse_tags({**riods.tags(), **riods.tags(1)})
+    # remove attributes with informaiton
+    # that should be added by GDAL/rasterio
+    for unwanted_attr in FILL_VALUE_NAMES + UNWANTED_RIO_ATTRS:
+        attrs.pop(unwanted_attr, None)
     if riods.nodata is not None:
         # The nodata values for the raster bands
         attrs["_FillValue"] = riods.nodata
@@ -706,8 +740,8 @@ def _decode_datetime_cf(
 
 def _parse_driver_tags(
     riods: RasterioReader,
-    attrs: Dict,
-    coords: Dict,
+    attrs: dict,
+    coords: dict,
 ) -> None:
     # Parse extra metadata from tags, if supported
     parsers = {"ENVI": _parse_envi}
@@ -719,8 +753,8 @@ def _parse_driver_tags(
         for key, value in meta.items():
             # Add values as coordinates if they match the band count,
             # as attributes otherwise
-            if isinstance(value, (list, np.ndarray)) and len(value) == riods.count:
-                coords[key] = ("band", np.asarray(value))
+            if isinstance(value, (list, numpy.ndarray)) and len(value) == riods.count:
+                coords[key] = ("band", numpy.asarray(value))
             else:
                 attrs[key] = value
 
@@ -739,10 +773,10 @@ def _pop_global_netcdf_attrs_from_vars(dataset_to_clean: Dataset) -> Dataset:
 
 
 def _subdataset_groups_to_dataset(
-    dim_groups: Dict[Hashable, Dict[Hashable, DataArray]], global_tags: Dict
-) -> Union[Dataset, List[Dataset]]:
+    dim_groups: dict[Hashable, dict[Hashable, DataArray]], global_tags: dict
+) -> Union[Dataset, list[Dataset]]:
     if dim_groups:
-        dataset: Union[Dataset, List[Dataset]] = []
+        dataset: Union[Dataset, list[Dataset]] = []
         for dim_group in dim_groups.values():
             dataset_group = _pop_global_netcdf_attrs_from_vars(
                 Dataset(dim_group, attrs=global_tags)
@@ -764,10 +798,10 @@ def _subdataset_groups_to_dataset(
 
 def _load_subdatasets(
     riods: RasterioReader,
-    group: Optional[Union[str, List[str], Tuple[str, ...]]],
-    variable: Optional[Union[str, List[str], Tuple[str, ...]]],
+    group: Optional[Union[str, list[str], tuple[str, ...]]],
+    variable: Optional[Union[str, list[str], tuple[str, ...]]],
     parse_coordinates: bool,
-    chunks: Optional[Union[int, Tuple, Dict]],
+    chunks: Optional[Union[int, tuple, dict]],
     cache: Optional[bool],
     lock: Any,
     masked: bool,
@@ -775,11 +809,11 @@ def _load_subdatasets(
     decode_times: bool,
     decode_timedelta: Optional[bool],
     **open_kwargs,
-) -> Union[Dataset, List[Dataset]]:
+) -> Union[Dataset, list[Dataset]]:
     """
     Load in rasterio subdatasets
     """
-    dim_groups: Dict[Hashable, Dict[Hashable, DataArray]] = defaultdict(dict)
+    dim_groups: dict[Hashable, dict[Hashable, DataArray]] = defaultdict(dict)
     subdataset_filter = None
     if any((group, variable)):
         subdataset_filter = build_subdataset_filter(group, variable)
@@ -810,15 +844,16 @@ def _load_subdatasets(
 def _load_bands_as_variables(
     riods: RasterioReader,
     parse_coordinates: bool,
-    chunks: Optional[Union[int, Tuple, Dict]],
+    chunks: Optional[Union[int, tuple, dict]],
     cache: Optional[bool],
     lock: Any,
     masked: bool,
     mask_and_scale: bool,
     decode_times: bool,
     decode_timedelta: Optional[bool],
+    vrt_params: Optional[dict],
     **open_kwargs,
-) -> Union[Dataset, List[Dataset]]:
+) -> Union[Dataset, list[Dataset]]:
     """
     Load in rasterio bands as variables
     """
@@ -828,6 +863,7 @@ def _load_bands_as_variables(
         band_riods = SingleBandDatasetReader(
             riods=riods,
             bidx=band - 1,
+            vrt_params=vrt_params,
         )
         band_name = f"band_{band}"
         data_vars[band_name] = (
@@ -861,7 +897,7 @@ def _prepare_dask(
     result: DataArray,
     riods: RasterioReader,
     filename: Union[str, os.PathLike],
-    chunks: Union[int, Tuple, Dict],
+    chunks: Union[int, tuple, dict],
 ) -> DataArray:
     """
     Prepare the data for dask computations
@@ -950,19 +986,19 @@ def open_rasterio(
         SingleBandDatasetReader,
     ],
     parse_coordinates: Optional[bool] = None,
-    chunks: Optional[Union[int, Tuple, Dict]] = None,
+    chunks: Optional[Union[int, tuple, dict]] = None,
     cache: Optional[bool] = None,
     lock: Optional[Any] = None,
     masked: bool = False,
     mask_and_scale: bool = False,
-    variable: Optional[Union[str, List[str], Tuple[str, ...]]] = None,
-    group: Optional[Union[str, List[str], Tuple[str, ...]]] = None,
+    variable: Optional[Union[str, list[str], tuple[str, ...]]] = None,
+    group: Optional[Union[str, list[str], tuple[str, ...]]] = None,
     default_name: Optional[str] = None,
     decode_times: bool = True,
     decode_timedelta: Optional[bool] = None,
     band_as_variable: bool = False,
     **open_kwargs,
-) -> Union[Dataset, DataArray, List[Dataset]]:
+) -> Union[Dataset, DataArray, list[Dataset]]:
     # pylint: disable=too-many-statements,too-many-locals,too-many-branches
     """Open a file with rasterio (experimental).
 
@@ -1036,7 +1072,7 @@ def open_rasterio(
 
     Returns
     -------
-    :obj:`xarray.Dataset` | :obj:`xarray.DataArray` | List[:obj:`xarray.Dataset`]:
+    :obj:`xarray.Dataset` | :obj:`xarray.DataArray` | list[:obj:`xarray.Dataset`]:
         The newly created dataset(s).
     """
     parse_coordinates = True if parse_coordinates is None else parse_coordinates
@@ -1048,25 +1084,26 @@ def open_rasterio(
             _single_band_open,
             bidx=filename._bidx,
         )
+        vrt_params = filename._vrt_params
     if isinstance(filename, (rasterio.io.DatasetReader, SingleBandDatasetReader)):
         filename = filename.name
     elif isinstance(filename, rasterio.vrt.WarpedVRT):
         vrt = filename
         filename = vrt.src_dataset.name
-        vrt_params = dict(
-            src_crs=vrt.src_crs.to_string() if vrt.src_crs else None,
-            crs=vrt.dst_crs.to_string() if vrt.dst_crs else None,
-            resampling=vrt.resampling,
-            tolerance=vrt.tolerance,
-            src_nodata=vrt.src_nodata,
-            nodata=vrt.dst_nodata,
-            width=vrt.dst_width,
-            height=vrt.dst_height,
-            src_transform=vrt.src_transform,
-            transform=vrt.dst_transform,
-            dtype=vrt.working_dtype,
+        vrt_params = {
+            "src_crs": vrt.src_crs.to_string() if vrt.src_crs else None,
+            "crs": vrt.dst_crs.to_string() if vrt.dst_crs else None,
+            "resampling": vrt.resampling,
+            "tolerance": vrt.tolerance,
+            "src_nodata": vrt.src_nodata,
+            "nodata": vrt.dst_nodata,
+            "width": vrt.dst_width,
+            "height": vrt.dst_height,
+            "src_transform": vrt.src_transform,
+            "transform": vrt.dst_transform,
+            "dtype": vrt.working_dtype,
             **vrt.warp_extras,
-        )
+        }
 
     if lock in (True, None):
         lock = RASTERIO_LOCK
@@ -1087,22 +1124,6 @@ def open_rasterio(
         riods = manager.acquire()
         captured_warnings = rio_warnings.copy()
 
-    if band_as_variable:
-        dataset_result = _load_bands_as_variables(
-            riods=riods,
-            parse_coordinates=parse_coordinates,
-            chunks=chunks,
-            cache=cache,
-            lock=lock,
-            masked=masked,
-            mask_and_scale=mask_and_scale,
-            decode_times=decode_times,
-            decode_timedelta=decode_timedelta,
-            **open_kwargs,
-        )
-        manager.close()
-        return dataset_result
-
     # raise the NotGeoreferencedWarning if applicable
     for rio_warning in captured_warnings:
         if not riods.subdatasets or not isinstance(
@@ -1129,12 +1150,28 @@ def open_rasterio(
         manager.close()
         return subdataset_result
 
-    if vrt_params is not None:
-        riods = WarpedVRT(riods, **vrt_params)
+    if band_as_variable:
+        dataset_result = _load_bands_as_variables(
+            riods=riods,
+            parse_coordinates=parse_coordinates,
+            chunks=chunks,
+            cache=cache,
+            lock=lock,
+            masked=masked,
+            mask_and_scale=mask_and_scale,
+            decode_times=decode_times,
+            decode_timedelta=decode_timedelta,
+            vrt_params=vrt_params,
+            **open_kwargs,
+        )
+        manager.close()
+        return dataset_result
 
     if cache is None:
         cache = chunks is None
 
+    riods = _ensure_warped_vrt(riods, vrt_params)
+
     # Get bands
     if riods.count < 1:
         raise ValueError("Unknown dims")
@@ -1156,7 +1193,7 @@ def open_rasterio(
             break
     else:
         coord_name = "band"
-        coords[coord_name] = np.asarray(riods.indexes)
+        coords[coord_name] = numpy.asarray(riods.indexes)
 
     has_gcps = riods.gcps[0]
     if has_gcps:
@@ -1169,7 +1206,7 @@ def open_rasterio(
         )
 
     unsigned = None
-    encoding: Dict[Hashable, Any] = {}
+    encoding: dict[Hashable, Any] = {}
     if mask_and_scale and "_Unsigned" in attrs:
         unsigned = variables.pop_to(attrs, encoding, "_Unsigned") == "true"
 
@@ -1199,7 +1236,7 @@ def open_rasterio(
     )
     result.encoding = encoding
 
-    # update attributes from NetCDF attributess
+    # update attributes from NetCDF attributes
     _load_netcdf_attrs(riods.tags(), result)
     result = _decode_datetime_cf(
         result, decode_times=decode_times, decode_timedelta=decode_timedelta
@@ -1225,6 +1262,12 @@ def open_rasterio(
 
     if chunks is not None:
         result = _prepare_dask(result, riods, filename, chunks)
+    else:
+        result.encoding["preferred_chunks"] = {
+            result.rio.y_dim: riods.block_shapes[0][0],
+            result.rio.x_dim: riods.block_shapes[0][1],
+            coord_name: 1,
+        }
 
     # add file path to encoding
     result.encoding["source"] = riods.name
