@@ -10,35 +10,24 @@ datacube is licensed under the Apache License, Version 2.0:
 
 """
 import copy
-import importlib.metadata
 import os
+from collections.abc import Hashable, Iterable, Mapping
 from pathlib import Path
-from typing import (
-    Any,
-    Dict,
-    Hashable,
-    Iterable,
-    List,
-    Literal,
-    Mapping,
-    Optional,
-    Tuple,
-    Union,
-)
+from typing import Any, Literal, Optional, Union
 
-import numpy as np
+import numpy
 import rasterio
 import rasterio.mask
 import rasterio.warp
 import xarray
 from affine import Affine
-from packaging import version
 from rasterio.dtypes import dtype_rev
 from rasterio.enums import Resampling
 from rasterio.features import geometry_mask
 from xarray.backends.file_manager import FileManager
 from xarray.core.dtypes import get_fill_value
 
+from rioxarray._io import FILL_VALUE_NAMES, UNWANTED_RIO_ATTRS
 from rioxarray.crs import crs_from_user_input
 from rioxarray.exceptions import (
     MissingCRS,
@@ -46,12 +35,7 @@ from rioxarray.exceptions import (
     OneDimensionalRaster,
     RioXarrayError,
 )
-from rioxarray.raster_writer import (
-    FILL_VALUE_NAMES,
-    UNWANTED_RIO_ATTRS,
-    RasterioWriter,
-    _ensure_nodata_dtype,
-)
+from rioxarray.raster_writer import RasterioWriter, _ensure_nodata_dtype
 from rioxarray.rioxarray import (
     XRasterBase,
     _get_data_var_message,
@@ -59,10 +43,6 @@ from rioxarray.rioxarray import (
     _order_bounds,
 )
 
-_RASTERIO_GTE_12 = version.parse(
-    importlib.metadata.version("rasterio")
-) >= version.parse("1.2")
-
 # DTYPE TO NODATA MAP
 # Based on: https://github.com/OSGeo/gdal/blob/
 # dee861e7c91c2da7ef8ff849947713e4d9bd115c/
@@ -87,7 +67,7 @@ _NODATA_DTYPE_MAP = {
 
 def _generate_attrs(
     src_data_array: xarray.DataArray, dst_nodata: Optional[float]
-) -> Dict[str, Any]:
+) -> dict[str, Any]:
     # add original attributes
     new_attrs = copy.deepcopy(src_data_array.attrs)
     # remove all nodata information
@@ -140,8 +120,8 @@ def _make_dst_affine(
     src_data_array: xarray.DataArray,
     src_crs: rasterio.crs.CRS,
     dst_crs: rasterio.crs.CRS,
-    dst_resolution: Optional[Union[float, Tuple[float, float]]] = None,
-    dst_shape: Optional[Tuple[float, float]] = None,
+    dst_resolution: Optional[Union[float, tuple[float, float]]] = None,
+    dst_shape: Optional[tuple[float, float]] = None,
     **kwargs,
 ):
     """Determine the affine of the new projected `xarray.DataArray`"""
@@ -190,9 +170,11 @@ def _clip_from_disk(
             invert=invert,
             crop=drop,
         )
-        if xds.rio.encoded_nodata is not None and not np.isnan(xds.rio.encoded_nodata):
-            out_image = out_image.astype(np.float64)
-            out_image[out_image == xds.rio.encoded_nodata] = np.nan
+        if xds.rio.encoded_nodata is not None and not numpy.isnan(
+            xds.rio.encoded_nodata
+        ):
+            out_image = out_image.astype(numpy.float64)
+            out_image[out_image == xds.rio.encoded_nodata] = numpy.nan
 
         height, width = out_image.shape[-2:]
         cropped_ds = xarray.DataArray(
@@ -236,10 +218,10 @@ def _clip_xarray(
         )
         cropped_ds = cropped_ds.rio.isel_window(
             rasterio.windows.get_data_window(
-                np.ma.masked_array(clip_mask_arr, ~clip_mask_arr)
+                numpy.ma.masked_array(clip_mask_arr, ~clip_mask_arr)
             )
         )
-    if xds.rio.nodata is not None and not np.isnan(xds.rio.nodata):
+    if xds.rio.nodata is not None and not numpy.isnan(xds.rio.nodata):
         cropped_ds = cropped_ds.fillna(xds.rio.nodata)
 
     return cropped_ds.astype(xds.dtype)
@@ -326,11 +308,9 @@ class RasterArray(XRasterBase):
         if input_nodata is not False:
             input_nodata = _ensure_nodata_dtype(input_nodata, self._obj.dtype)
             if encoded:
-                data_obj.rio.update_encoding(
-                    dict(_FillValue=input_nodata), inplace=True
-                )
+                data_obj.rio.update_encoding({"_FillValue": input_nodata}, inplace=True)
             else:
-                data_obj.rio.update_attrs(dict(_FillValue=input_nodata), inplace=True)
+                data_obj.rio.update_attrs({"_FillValue": input_nodata}, inplace=True)
         if input_nodata is False or encoded:
             new_attrs = dict(data_obj.attrs)
             new_attrs.pop("_FillValue", None)
@@ -388,8 +368,8 @@ class RasterArray(XRasterBase):
     def reproject(
         self,
         dst_crs: Any,
-        resolution: Optional[Union[float, Tuple[float, float]]] = None,
-        shape: Optional[Tuple[int, int]] = None,
+        resolution: Optional[Union[float, tuple[float, float]]] = None,
+        shape: Optional[tuple[int, int]] = None,
         transform: Optional[Affine] = None,
         resampling: Resampling = Resampling.nearest,
         nodata: Optional[float] = None,
@@ -405,6 +385,10 @@ class RasterArray(XRasterBase):
             a 'crs' attribute to be set containing a valid CRS.
             If using a WKT (e.g. from spatiareference.org), make sure it is an OGC WKT.
 
+        .. note:: To re-project with dask, see
+            `odc-geo <https://odc-geo.readthedocs.io/>`__ &
+            `pyresample <https://pyresample.readthedocs.io/>`__.
+
         .. versionadded:: 0.0.27 shape
         .. versionadded:: 0.0.28 transform
         .. versionadded:: 0.5.0 nodata, kwargs
@@ -484,7 +468,7 @@ class RasterArray(XRasterBase):
         # add necessary attributes
         new_attrs = _generate_attrs(self._obj, dst_nodata)
         # make sure dimensions with coordinates renamed to x,y
-        dst_dims: List[Hashable] = []
+        dst_dims: list[Hashable] = []
         for dim in self._obj.dims:
             if dim == self.x_dim:
                 dst_dims.append("x")
@@ -520,15 +504,15 @@ class RasterArray(XRasterBase):
         dst_nodata = default_nodata if nodata is None else nodata
         return dst_nodata
 
-    def _create_dst_data(self, dst_height: int, dst_width: int) -> np.ndarray:
+    def _create_dst_data(self, dst_height: int, dst_width: int) -> numpy.ndarray:
         extra_dim = self._check_dimensions()
         if extra_dim:
-            dst_data = np.zeros(
+            dst_data = numpy.zeros(
                 (self._obj[extra_dim].size, dst_height, dst_width),
                 dtype=self._obj.dtype.type,
             )
         else:
-            dst_data = np.zeros((dst_height, dst_width), dtype=self._obj.dtype.type)
+            dst_data = numpy.zeros((dst_height, dst_width), dtype=self._obj.dtype.type)
         return dst_data
 
     def reproject_match(
@@ -600,7 +584,7 @@ class RasterArray(XRasterBase):
         maxx: float,
         maxy: float,
         constant_values: Union[
-            float, Tuple[int, int], Mapping[Any, Tuple[int, int]], None
+            float, tuple[int, int], Mapping[Any, tuple[int, int]], None
         ] = None,
     ) -> xarray.DataArray:
         """Pad the array to x,y bounds.
@@ -619,7 +603,7 @@ class RasterArray(XRasterBase):
             Maximum bound for y coordinate.
         constant_values: scalar, tuple or mapping of hashable to tuple
             The value used for padding. If None, nodata will be used if it is
-            set, and np.nan otherwise.
+            set, and numpy.nan otherwise.
 
 
         Returns
@@ -632,33 +616,33 @@ class RasterArray(XRasterBase):
         resolution_x, resolution_y = self.resolution()
         y_before = y_after = 0
         x_before = x_after = 0
-        y_coord: Union[xarray.DataArray, np.ndarray] = self._obj[self.y_dim]
-        x_coord: Union[xarray.DataArray, np.ndarray] = self._obj[self.x_dim]
+        y_coord: Union[xarray.DataArray, numpy.ndarray] = self._obj[self.y_dim]
+        x_coord: Union[xarray.DataArray, numpy.ndarray] = self._obj[self.x_dim]
 
         if top - resolution_y < maxy:
-            new_y_coord: np.ndarray = np.arange(bottom, maxy, -resolution_y)[::-1]
+            new_y_coord: numpy.ndarray = numpy.arange(bottom, maxy, -resolution_y)[::-1]
             y_before = len(new_y_coord) - len(y_coord)
             y_coord = new_y_coord
             top = y_coord[0]
         if bottom + resolution_y > miny:
-            new_y_coord = np.arange(top, miny, resolution_y)
+            new_y_coord = numpy.arange(top, miny, resolution_y)
             y_after = len(new_y_coord) - len(y_coord)
             y_coord = new_y_coord
             bottom = y_coord[-1]
 
         if left - resolution_x > minx:
-            new_x_coord: np.ndarray = np.arange(right, minx, -resolution_x)[::-1]
+            new_x_coord: numpy.ndarray = numpy.arange(right, minx, -resolution_x)[::-1]
             x_before = len(new_x_coord) - len(x_coord)
             x_coord = new_x_coord
             left = x_coord[0]
         if right + resolution_x < maxx:
-            new_x_coord = np.arange(left, maxx, resolution_x)
+            new_x_coord = numpy.arange(left, maxx, resolution_x)
             x_after = len(new_x_coord) - len(x_coord)
             x_coord = new_x_coord
             right = x_coord[-1]
 
         if constant_values is None:
-            constant_values = np.nan if self.nodata is None else self.nodata
+            constant_values = numpy.nan if self.nodata is None else self.nodata
 
         superset = self._obj.pad(
             pad_width={
@@ -679,7 +663,7 @@ class RasterArray(XRasterBase):
         maxx: float,
         maxy: float,
         constant_values: Union[
-            float, Tuple[int, int], Mapping[Any, Tuple[int, int]], None
+            float, tuple[int, int], Mapping[Any, tuple[int, int]], None
         ] = None,
     ) -> xarray.DataArray:
         """Pad the :obj:`xarray.DataArray` to a bounding box
@@ -698,7 +682,7 @@ class RasterArray(XRasterBase):
             Maximum bound for y coordinate.
         constant_values: scalar, tuple or mapping of hashable to tuple
             The value used for padding. If None, nodata will be used if it is
-            set, and np.nan otherwise.
+            set, and numpy.nan otherwise.
 
 
         Returns
@@ -808,10 +792,10 @@ class RasterArray(XRasterBase):
         window_error = None
         try:
             window = rasterio.windows.from_bounds(
-                left=np.array(left).item(),
-                bottom=np.array(bottom).item(),
-                right=np.array(right).item(),
-                top=np.array(top).item(),
+                left=numpy.array(left).item(),
+                bottom=numpy.array(bottom).item(),
+                right=numpy.array(right).item(),
+                top=numpy.array(top).item(),
                 transform=self.transform(recalc=True),
             )
             cl_array: xarray.DataArray = self.isel_window(window)  # type: ignore
@@ -879,7 +863,7 @@ class RasterArray(XRasterBase):
         Parameters
         ----------
         geometries: Iterable
-            A list of geojson geometry dicts or objects with __geom_interface__ with
+            A list of geojson geometry dicts or objects with __geo_interface__ with
             if you have rasterio 1.2+.
         crs: :obj:`rasterio.crs.CRS`, optional
             The CRS of the input geometries. Default is to assume it is the same
@@ -913,13 +897,7 @@ class RasterArray(XRasterBase):
             )
         crs = crs_from_user_input(crs) if crs is not None else self.crs
         if self.crs != crs:
-            if _RASTERIO_GTE_12:
-                geometries = rasterio.warp.transform_geom(crs, self.crs, geometries)
-            else:
-                geometries = [
-                    rasterio.warp.transform_geom(crs, self.crs, geometry)
-                    for geometry in geometries
-                ]
+            geometries = rasterio.warp.transform_geom(crs, self.crs, geometries)
         cropped_ds = None
         if from_disk:
             cropped_ds = _clip_from_disk(
@@ -953,7 +931,7 @@ class RasterArray(XRasterBase):
 
     def _interpolate_na(
         self, src_data: Any, method: Literal["linear", "nearest", "cubic"] = "nearest"
-    ) -> np.ndarray:
+    ) -> numpy.ndarray:
         """
         This method uses scipy.interpolate.griddata to interpolate missing data.
 
@@ -980,18 +958,18 @@ class RasterArray(XRasterBase):
 
         src_data_flat = src_data.flatten()
         try:
-            data_isnan = np.isnan(self.nodata)  # type: ignore
+            data_isnan = numpy.isnan(self.nodata)  # type: ignore
         except TypeError:
             data_isnan = False
         if not data_isnan:
             data_bool = src_data_flat != self.nodata
         else:
-            data_bool = ~np.isnan(src_data_flat)
+            data_bool = ~numpy.isnan(src_data_flat)
 
         if not data_bool.any():
             return src_data
 
-        x_coords, y_coords = np.meshgrid(
+        x_coords, y_coords = numpy.meshgrid(
             self._obj.coords[self.x_dim].values, self._obj.coords[self.y_dim].values
         )
 
@@ -1034,7 +1012,7 @@ class RasterArray(XRasterBase):
                 interp_data.append(
                     self._interpolate_na(sub_xds.load().data, method=method)
                 )
-            interp_data = np.array(interp_data)  # type: ignore
+            interp_data = numpy.array(interp_data)  # type: ignore
         else:
             interp_data = self._interpolate_na(self._obj.load().data, method=method)  # type: ignore
 
@@ -1056,8 +1034,8 @@ class RasterArray(XRasterBase):
         self,
         raster_path: Union[str, os.PathLike],
         driver: Optional[str] = None,
-        dtype: Optional[Union[str, np.dtype]] = None,
-        tags: Optional[Dict[str, str]] = None,
+        dtype: Optional[Union[str, numpy.dtype]] = None,
+        tags: Optional[dict[str, str]] = None,
         windowed: bool = False,
         recalc_transform: bool = True,
         lock: Optional[bool] = None,
@@ -1112,9 +1090,8 @@ class RasterArray(XRasterBase):
         """
         if driver is None:
             extension = Path(raster_path).suffix
-            # https://github.com/rasterio/rasterio/pull/2634
             # https://github.com/rasterio/rasterio/pull/2008
-            if not _RASTERIO_GTE_12 or extension in (".tif", ".tiff"):
+            if extension in (".tif", ".tiff"):
                 driver = "GTiff"
 
         # get the output profile from the rasterio object
