@@ -3,10 +3,11 @@ This module is an extension for xarray to provide rasterio capabilities
 to xarray datasets.
 """
 import os
-from typing import Any, Dict, Iterable, List, Literal, Mapping, Optional, Tuple, Union
+from collections.abc import Iterable, Mapping
+from typing import Any, Literal, Optional, Union
 from uuid import uuid4
 
-import numpy as np
+import numpy
 import rasterio.crs
 import xarray
 from affine import Affine
@@ -22,7 +23,7 @@ class RasterDataset(XRasterBase):
     """This is the GIS extension for :class:`xarray.Dataset`"""
 
     @property
-    def vars(self) -> List:
+    def vars(self) -> list:
         """list: Returns non-coordinate varibles"""
         return list(self._obj.data_vars)
 
@@ -57,8 +58,8 @@ class RasterDataset(XRasterBase):
     def reproject(
         self,
         dst_crs: Any,
-        resolution: Optional[Union[float, Tuple[float, float]]] = None,
-        shape: Optional[Tuple[int, int]] = None,
+        resolution: Optional[Union[float, tuple[float, float]]] = None,
+        shape: Optional[tuple[int, int]] = None,
         transform: Optional[Affine] = None,
         resampling: Resampling = Resampling.nearest,
         nodata: Optional[float] = None,
@@ -73,6 +74,10 @@ class RasterDataset(XRasterBase):
             a 'crs' attribute to be set containing a valid CRS.
             If using a WKT (e.g. from spatiareference.org), make sure it is an OGC WKT.
 
+        .. note:: To re-project with dask, see
+            `odc-geo <https://odc-geo.readthedocs.io/>`__ &
+            `pyresample <https://pyresample.readthedocs.io/>`__.
+
         .. versionadded:: 0.0.27 shape
         .. versionadded:: 0.0.28 transform
         .. versionadded:: 0.5.0 nodata, kwargs
@@ -194,7 +199,7 @@ class RasterDataset(XRasterBase):
         maxx: float,
         maxy: float,
         constant_values: Union[
-            float, Tuple[int, int], Mapping[Any, Tuple[int, int]], None
+            float, tuple[int, int], Mapping[Any, tuple[int, int]], None
         ] = None,
     ) -> xarray.Dataset:
         """Pad the :class:`xarray.Dataset` to a bounding box.
@@ -216,7 +221,7 @@ class RasterDataset(XRasterBase):
             Maximum bound for y coordinate.
         constant_values: scalar, tuple or mapping of hashable to tuple
             The value used for padding. If None, nodata will be used if it is
-            set, and np.nan otherwise.
+            set, and numpy.nan otherwise.
 
         Returns
         -------
@@ -441,8 +446,8 @@ class RasterDataset(XRasterBase):
         self,
         raster_path: Union[str, os.PathLike],
         driver: Optional[str] = None,
-        dtype: Optional[Union[str, np.dtype]] = None,
-        tags: Optional[Dict[str, str]] = None,
+        dtype: Optional[Union[str, numpy.dtype]] = None,
+        tags: Optional[dict[str, str]] = None,
         windowed: bool = False,
         recalc_transform: bool = True,
         lock: Optional[bool] = None,
@@ -517,7 +522,7 @@ class RasterDataset(XRasterBase):
         nodata = nodatavals[0]
         if (
             all(nodataval == nodata for nodataval in nodatavals)
-            or np.isnan(nodatavals).all()
+            or numpy.isnan(nodatavals).all()
         ):
             data_array.rio.write_nodata(nodata, inplace=True)
         else:
