@@ -15,7 +15,7 @@ import rasterio
 from rasterio.windows import Window
 from xarray.conventions import encode_cf_variable
 
-from rioxarray._io import _get_unsigned_dtype
+from rioxarray._io import FILL_VALUE_NAMES, UNWANTED_RIO_ATTRS, _get_unsigned_dtype
 from rioxarray.exceptions import RioXarrayError
 
 try:
@@ -31,8 +31,6 @@ except ImportError:
         return False
 
 
-FILL_VALUE_NAMES = ("_FillValue", "missing_value", "fill_value", "nodata")
-UNWANTED_RIO_ATTRS = ("nodatavals", "is_tiled", "res")
 # Note: transform & crs are removed in write_transform/write_crs
 
 
@@ -153,7 +151,7 @@ def _get_dtypes(rasterio_dtype, encoded_rasterio_dtype, dataarray_dtype):
 
     Returns
     -------
-    Tuple[Union[str, numpy.dtype], Union[str, numpy.dtype]]:
+    tuple[Union[str, numpy.dtype], Union[str, numpy.dtype]]:
         The rasterio dtype and numpy dtype.
     """
     # SCENARIO 1: User wants to write to complex_int16
@@ -239,10 +237,10 @@ class RasterioWriter:
             Call ".compute()" on the Delayed object to compute the result
             later. Call ``dask.compute(delayed1, delayed2)`` to save
             multiple delayed files at once.
-        dtype: np.dtype
+        dtype: numpy.dtype
             Numpy-compliant dtype used to save raster. If data is not already
             represented by this dtype in memory it is recast. dtype='complex_int16'
-            is a special case to write in-memory np.complex64 to CInt16.
+            is a special case to write in-memory numpy.complex64 to CInt16.
         **kwargs
             Keyword arguments to pass into writing the raster.
         """
@@ -285,7 +283,9 @@ class RasterioWriter:
                         out_data = xarray_dataarray.rio.isel_window(window)
                     else:
                         out_data = xarray_dataarray
-                    data = encode_cf_variable(out_data).values.astype(numpy_dtype)
+                    data = encode_cf_variable(out_data.variable).values.astype(
+                        numpy_dtype
+                    )
                     if data.ndim == 2:
                         rds.write(data, 1, window=window)
                     else:
@@ -293,7 +293,7 @@ class RasterioWriter:
 
         if lock and is_dask_collection(xarray_dataarray.data):
             return dask.array.store(
-                encode_cf_variable(xarray_dataarray).data.astype(numpy_dtype),
+                encode_cf_variable(xarray_dataarray.variable).data.astype(numpy_dtype),
                 self,
                 lock=lock,
                 compute=compute,
