@@ -14,6 +14,8 @@ import rasterio.warp
 import rasterio.windows
 import xarray
 from affine import Affine
+from pyproj.aoi import AreaOfInterest
+from pyproj.database import query_utm_crs_info
 from rasterio.control import GroundControlPoint
 from rasterio.crs import CRS
 
@@ -531,13 +533,6 @@ class XRasterBase:
         -------
         rasterio.crs.CRS
         """
-        # pylint: disable=import-outside-toplevel
-        try:
-            from pyproj.aoi import AreaOfInterest
-            from pyproj.database import query_utm_crs_info
-        except ImportError:
-            raise RuntimeError("pyproj 3+ required for estimate_utm_crs.") from None
-
         if self.crs is None:
             raise RuntimeError("crs must be set to estimate UTM CRS.")
 
@@ -1253,18 +1248,20 @@ class XRasterBase:
         except (KeyError, AttributeError):
             return None
 
-        gcps = [
-            GroundControlPoint(
-                x=gcp["geometry"]["coordinates"][0],
-                y=gcp["geometry"]["coordinates"][1],
-                z=gcp["geometry"]["coordinates"][2],
+        def _parse_gcp(gcp) -> GroundControlPoint:
+            x, y, *z = gcp["geometry"]["coordinates"]
+            z = z[0] if z else None
+            return GroundControlPoint(
+                x=x,
+                y=y,
+                z=z,
                 row=gcp["properties"]["row"],
                 col=gcp["properties"]["col"],
                 id=gcp["properties"]["id"],
                 info=gcp["properties"]["info"],
             )
-            for gcp in geojson_gcps["features"]
-        ]
+
+        gcps = [_parse_gcp(gcp) for gcp in geojson_gcps["features"]]
         return gcps
 
 
@@ -1282,6 +1279,12 @@ def _convert_gcps_to_geojson(
     -------
     A FeatureCollection dict.
     """
+
+    def _gcp_coordinates(gcp):
+        if gcp.z is None:
+            return [gcp.x, gcp.y]
+        return [gcp.x, gcp.y, gcp.z]
+
     features = [
         {
             "type": "Feature",
@@ -1291,7 +1294,7 @@ def _convert_gcps_to_geojson(
                 "row": gcp.row,
                 "col": gcp.col,
             },
-            "geometry": {"type": "Point", "coordinates": [gcp.x, gcp.y, gcp.z]},
+            "geometry": {"type": "Point", "coordinates": _gcp_coordinates(gcp)},
         }
         for gcp in gcps
     ]
