@@ -5,7 +5,7 @@ through a backend entrypoint.
 # pylint: disable=arguments-differ
 import os.path
 
-import xarray as xr
+import xarray
 
 from . import _io
 from .exceptions import RioXarrayError
@@ -26,7 +26,7 @@ CAN_OPEN_EXTS = {
 }
 
 
-class RasterioBackend(xr.backends.common.BackendEntrypoint):
+class RasterioBackend(xarray.backends.common.BackendEntrypoint):
     """
     Requires xarray 0.18+
 
@@ -38,8 +38,6 @@ class RasterioBackend(xr.backends.common.BackendEntrypoint):
         filename_or_obj,
         drop_variables=None,
         parse_coordinates=None,
-        chunks=None,
-        cache=None,
         lock=None,
         masked=False,
         mask_and_scale=True,
@@ -56,8 +54,7 @@ class RasterioBackend(xr.backends.common.BackendEntrypoint):
         rds = _io.open_rasterio(
             filename_or_obj,
             parse_coordinates=parse_coordinates,
-            chunks=chunks,
-            cache=cache,
+            cache=False,
             lock=lock,
             masked=masked,
             mask_and_scale=mask_and_scale,
@@ -69,7 +66,7 @@ class RasterioBackend(xr.backends.common.BackendEntrypoint):
             band_as_variable=band_as_variable,
             **open_kwargs,
         )
-        if isinstance(rds, xr.DataArray):
+        if isinstance(rds, xarray.DataArray):
             dataset = rds.to_dataset()
             dataset.set_close(rds._close)
             rds = dataset
