@@ -6,7 +6,7 @@ from numpy.testing import assert_almost_equal
 
 from rioxarray import open_rasterio
 from rioxarray.merge import merge_arrays, merge_datasets
-from test.conftest import RASTERIO_GE_13, RASTERIO_GE_125, TEST_INPUT_DATA_DIR
+from test.conftest import TEST_INPUT_DATA_DIR
 
 
 @pytest.mark.parametrize("squeeze", [True, False])
@@ -26,26 +26,12 @@ def test_merge_arrays(squeeze):
             arrays = [array.squeeze() for array in arrays]
         merged = merge_arrays(arrays)
 
-        if RASTERIO_GE_125:
-            assert_almost_equal(
-                merged.rio.bounds(),
-                (-7274009.6494863, 5003777.3385, -7227678.3778335, 5050108.6101528),
-            )
-            assert merged.rio.shape == (200, 200)
-            assert_almost_equal(merged.sum(), 22865733)
-
-        else:
-            assert_almost_equal(
-                merged.rio.bounds(),
-                (
-                    -7274009.649486291,
-                    5003545.682141737,
-                    -7227446.721475236,
-                    5050108.61015275,
-                ),
-            )
-            assert merged.rio.shape == (201, 201)
-            assert_almost_equal(merged.sum(), 11368261)
+        assert_almost_equal(
+            merged.rio.bounds(),
+            (-7274009.6494863, 5003777.3385, -7227678.3778335, 5050108.6101528),
+        )
+        assert merged.rio.shape == (200, 200)
+        assert_almost_equal(merged.sum(), 22865733)
 
         assert_almost_equal(
             tuple(merged.rio.transform()),
@@ -91,23 +77,13 @@ def test_merge__different_crs(dataset):
             test_sum = merged[merged.rio.vars[0]].sum()
         else:
             test_sum = merged.sum()
-        if RASTERIO_GE_125:
-            assert_almost_equal(
-                merged.rio.bounds(),
-                (-7300984.0238134, 5003618.5908794, -7224054.1109682, 5050108.6101528),
-            )
-            assert merged.rio.shape == (84, 139)
-            if RASTERIO_GE_13:
-                assert_almost_equal(test_sum, -131734881)
-            else:
-                assert_almost_equal(test_sum, -128605446)
-        else:
-            assert_almost_equal(
-                merged.rio.bounds(),
-                (-7300984.0238134, 5003618.5908794, -7223500.6583578, 5050108.6101528),
-            )
-            assert merged.rio.shape == (84, 140)
-            assert_almost_equal(test_sum, -131013894)
+        assert_almost_equal(
+            merged.rio.bounds(),
+            (-7300984.0238134, 5003618.5908794, -7224054.1109682, 5050108.6101528),
+        )
+        assert merged.rio.shape == (84, 139)
+        assert_almost_equal(test_sum, -131734881)
+
         assert_almost_equal(
             tuple(merged.rio.transform()),
             (
@@ -148,18 +124,11 @@ def test_merge_arrays__res():
         ]
         merged = merge_arrays(arrays, res=(300, 300))
 
-        if RASTERIO_GE_125:
-            assert_almost_equal(
-                merged.rio.bounds(),
-                (-7274009.6494863, 5003608.6101528, -7227509.6494863, 5050108.6101528),
-            )
-            assert merged.rio.shape == (155, 155)
-        else:
-            assert_almost_equal(
-                merged.rio.bounds(),
-                (-7274009.6494863, 5003308.6101528, -7227209.6494863, 5050108.6101528),
-            )
-            assert merged.rio.shape == (156, 156)
+        assert_almost_equal(
+            merged.rio.bounds(),
+            (-7274009.6494863, 5003608.6101528, -7227509.6494863, 5050108.6101528),
+        )
+        assert merged.rio.shape == (155, 155)
 
         assert_almost_equal(
             tuple(merged.rio.transform()),
@@ -214,25 +183,12 @@ def test_merge_datasets():
             "sur_refl_b07_1",
         ]
         data_var = data_vars[0]
-        if RASTERIO_GE_125:
-            assert_almost_equal(
-                merged[data_var].rio.bounds(),
-                (-4447802.078667, -10007554.677, -3335851.559, -8895604.157333),
-            )
-            assert merged.rio.shape == (2400, 2400)
-            assert_almost_equal(merged[data_var].sum(), 4539666606551516)
-        else:
-            assert_almost_equal(
-                merged[data_var].rio.bounds(),
-                (
-                    -4447802.078667,
-                    -10008017.989716524,
-                    -3335388.246283474,
-                    -8895604.157333,
-                ),
-            )
-            assert merged.rio.shape == (2401, 2401)
-            assert_almost_equal(merged[data_var].sum(), 4543446965182987)
+        assert_almost_equal(
+            merged[data_var].rio.bounds(),
+            (-4447802.078667, -10007554.677, -3335851.559, -8895604.157333),
+        )
+        assert merged.rio.shape == (2400, 2400)
+        assert_almost_equal(merged[data_var].sum(), 4539666606551516)
         assert_almost_equal(
             tuple(merged[data_var].rio.transform()),
             (
