@@ -5,25 +5,26 @@ import pytest
 from rioxarray.exceptions import RioXarrayError
 from test.conftest import TEST_INPUT_DATA_DIR
 
-xr = pytest.importorskip("xarray", minversion="0.18")
+xarray = pytest.importorskip("xarray", minversion="0.18")
 
 
 def test_xarray_open_dataset():
     cog_file = os.path.join(TEST_INPUT_DATA_DIR, "cog.tif")
 
-    ds = xr.open_dataset(cog_file, engine="rasterio")
+    ds = xarray.open_dataset(cog_file, engine="rasterio")
 
-    assert isinstance(ds, xr.Dataset)
+    assert isinstance(ds, xarray.Dataset)
     assert "band_data" in ds.data_vars
     assert ds.data_vars["band_data"].shape == (1, 500, 500)
     assert "spatial_ref" not in ds.data_vars
     assert "spatial_ref" in ds.coords
     assert "grid_mapping" not in ds.data_vars["band_data"].attrs
     assert "grid_mapping" in ds.data_vars["band_data"].encoding
+    assert "preferred_chunks" in ds.data_vars["band_data"].encoding
 
-    ds = xr.open_dataset(cog_file)
+    ds = xarray.open_dataset(cog_file)
 
-    assert isinstance(ds, xr.Dataset)
+    assert isinstance(ds, xarray.Dataset)
 
 
 def test_xarray_open_dataset__drop_variables():
@@ -31,7 +32,7 @@ def test_xarray_open_dataset__drop_variables():
         TEST_INPUT_DATA_DIR, "MOD09GA.A2008296.h14v17.006.2015181011753.hdf"
     )
 
-    with xr.open_dataset(
+    with xarray.open_dataset(
         input_file,
         engine="rasterio",
         group="MODIS_Grid_500m_2D",
@@ -58,7 +59,7 @@ def test_open_multiple_resolution():
         RioXarrayError,
         match="Multiple resolution sets found. Use 'variable' or 'group' to filter.",
     ):
-        xr.open_dataset(
+        xarray.open_dataset(
             os.path.join(
                 TEST_INPUT_DATA_DIR, "MOD09GA.A2008296.h14v17.006.2015181011753.hdf"
             ),
